@@ -135,6 +135,7 @@ my %hierarchy = (
     'SlideComments' => 'ResourceBase',
     'SlideModernComment' => 'SlideCommentBase',
     'SlideProperties' => 'ResourceBase',
+    'SlideShowProperties' => 'ResourceBase',
     'Slides' => 'ResourceBase',
     'SolidFill' => 'FillFormat',
     'SplitDocumentResult' => 'ResourceBase',
@@ -377,6 +378,7 @@ my %determiners = (
     'SlideComments' => {  },
     'SlideModernComment' => { 'Type' => 'Modern', },
     'SlideProperties' => {  },
+    'SlideShowProperties' => {  },
     'Slides' => {  },
     'SolidFill' => { 'Type' => 'Solid', },
     'SplitDocumentResult' => {  },
